@@ -2,6 +2,7 @@ use serde::{Deserialize, Serialize};
 use std::collections::HashMap;
 use reqwest::blocking::Client;
 use std::{fs};
+use std::path::Path;
 use crate::{dbang_utils, deno_cli, deno_versions};
 
 #[derive(Serialize, Deserialize, Debug)]
@@ -14,9 +15,12 @@ pub struct Artifact {
     #[serde(rename(serialize = "script-ref", deserialize = "script-ref"))]
     pub script_ref: String,
     pub description: Option<String>,
+    pub compat: Option<bool>,
     #[serde(rename(serialize = "import-map", deserialize = "import-map"))]
     pub import_map: Option<String>,
     pub deno: Option<String>,
+    /// target os and arch, format as `os-arch`
+    pub target: Option<String>,
     pub permissions: Option<Vec<String>>,
 }
 
@@ -47,6 +51,15 @@ impl Artifact {
         };
     }
 
+    pub fn get_deno_config(&self, repo_name: &str) -> String {
+        let catalog_repo = Catalog::get_full_repo_name(repo_name);
+        let deno_config_file = dbang_utils::dbang_dir().join("catalogs/github").join(catalog_repo).join("deno.json");
+        if !deno_config_file.exists() {
+            std::fs::write(&deno_config_file, "{}").unwrap();
+        }
+        String::from(deno_config_file.to_string_lossy())
+    }
+
     pub fn get_deno_permissions(&self) -> Vec<String> {
         if let Some(permissions) = &self.permissions {
             return permissions.iter().map(|x| {
@@ -72,6 +85,18 @@ impl Artifact {
         }
         return "deno".to_string();
     }
+
+    pub fn is_target_compatible(&self) -> bool {
+        if let Some(target) = &self.target {
+            let os = std::env::consts::OS;
+            let arch = std::env::consts::ARCH;
+            let full_name = format!("{}-{}", os, arch);
+            return target.split(",").any(|x| {
+                x == os || x == full_name
+            });
+        }
+        return true;
+    }
 }
 
 impl Catalog {
@@ -97,8 +122,14 @@ impl Catalog {
             .join("catalogs/github")
             .join(catalog_full_name)
             .join("dbang-catalog.json");
-        let data = fs::read_to_string(dbang_catalog_json_file).expect("Unable to read dbang-catalog.json");
-        let catalog: Catalog = serde_json::from_str(&data).expect("Unable to parse dbang-catalog.json");
+        return Catalog::read_from_file(&dbang_catalog_json_file);
+    }
+
+    pub fn read_from_file(dbang_catalog_json_file: &Path) -> anyhow::Result<Catalog> {
+        let data = fs::read_to_string(dbang_catalog_json_file)
+            .expect(format!("Unable to read {}", dbang_catalog_json_file.to_string_lossy()).as_str());
+        let catalog: Catalog = serde_json::from_str(&data)
+            .expect(format!("Unable to parse {}", dbang_catalog_json_file.to_string_lossy()).as_str());
         Ok(catalog)
     }
 
@@ -111,6 +142,10 @@ impl Catalog {
         let dbang_catalog_file = dbang_catalog_dir.join("dbang-catalog.json");
         let json_text = serde_json::to_string(self)?;
         std::fs::write(&dbang_catalog_file, json_text)?;
+        let deno_config_file = dbang_catalog_dir.join("deno.json");
+        if !deno_config_file.exists() {
+            std::fs::write(&deno_config_file, "{}")?;
+        }
         Ok(())
     }
 
@@ -253,4 +288,22 @@ mod tests {
             println!("user = {}", user);
         }
     }
+
+    #[test]
+    fn test_is_target_compatible() {
+        let mut artifact = Artifact {
+            script_ref: "hello.ts".to_string(),
+            description: Some("Hello world".to_string()),
+            target: Some("macos".to_string()),
+            deno: None,
+            import_map: None,
+            permissions: None,
+            compat: None,
+        };
+        if cfg!(target_os = "macos") {
+            assert!(artifact.is_target_compatible());
+        } else {
+            assert!(!artifact.is_target_compatible());
+        }
+    }
 }
